@@ -2,7 +2,7 @@ import re
 import requests
 import time
 
-class deep_getstockinfo():
+class getStockInfo():
     def __init__(self,API = 'tencent'):
         self.api = API
         
